==> shared_package_flutter-0.0.11.tar.gz: lib/dialog/security_password.dart <==
import 'package:flutter/material.dart';

class FunctionClosed{
  Color buttonColor;
  Function onClosed;

  FunctionClosed({
    this.buttonColor,
    this.onClosed
  });
}

class FunctionOpened{
  Color buttonColor;
  Function onOpened;

  FunctionOpened({
    this.buttonColor,
    this.onOpened
  });
}

class SecurityPasswordParam{
  FunctionClosed fnClosed;
  FunctionOpened fnOpened;

  SecurityPasswordParam({
    this.fnClosed,
    this.fnOpened
  });
}

class SecurityPassword{

  static Widget show( BuildContext context, SecurityPasswordParam _param ){
    TextEditingController _textEditingControllerInformeSenha = TextEditingController( );

    return ListView(
      children: <Widget>[
        Padding(
          padding: EdgeInsets.only( top: 150.0, left: 50, right: 50 ),
          child: Container(
            height: 200,
            width: double.infinity,
            child: Card(
              color: Colors.white,
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular( 12.0 ),
              ),
              elevation: 10.0,
              child: Padding(
                padding: const EdgeInsets.all( 16.0 ),
                child: Form(
                  child: Column(
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.only( left: 25, right: 25 ),
                        child: TextFormField(
                          controller: _textEditingControllerInformeSenha,
                          keyboardType: TextInputType.text,
                          obscureText: true,
                          textInputAction: TextInputAction.next,
                          decoration: InputDecoration(
                            labelText: "Informe a senha"
                          ),
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.only( top: 25 ),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Container(
                              width: 100,
                              child: RaisedButton(
                                color: _param.fnClosed.buttonColor,
                                textColor: Colors.white,
                                padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                                child: Text(
                                  "Fechar",
                                  style: TextStyle( fontSize: 20.0 ),
                                ),
                                onPressed: ( ) {
                                  _param.fnClosed.onClosed();
                                }
                              )
                            ),
                            Padding( padding: EdgeInsets.only( left: 20 ) ),
                            Container(
                              width: 100,
                              child: RaisedButton(
                                color: _param.fnOpened.buttonColor,
                                textColor: Colors.white,
                                elevation: 5.0,
                                padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                                child: Text(
                                  "Abrir",
                                  style: TextStyle( fontSize: 20.0 ),
                                ),
                                onPressed: (){
                                  _param.fnOpened.onOpened();
                                }
                              )
                            )
                          ],
                        )
                      )
                    ],
                  ),
                ),
              ),
            )
          )
        )
      ],
    );
  }
}

==> shared_package_flutter-0.0.12.tar.gz: lib/dialog/security_password.dart <==
import 'package:flutter/material.dart';

class FunctionClosed{
  Color buttonColor;
  Function onClosed;

  FunctionClosed({
    this.buttonColor,
    this.onClosed
  });
}

class FunctionOpened{
  Color buttonColor;
  Function( String ) onOpened;

  FunctionOpened({
    this.buttonColor,
    this.onOpened
  });
}

class SecurityPasswordParam{
  FunctionClosed fnClosed;
  FunctionOpened fnOpened;

  SecurityPasswordParam({
    this.fnClosed,
    this.fnOpened
  });
}

class SecurityPassword{

  static Widget show( BuildContext context, SecurityPasswordParam _param ){
    TextEditingController _textEditingControllerInformeSenha = TextEditingController( );

    return ListView(
      children: <Widget>[
        Padding(
          padding: EdgeInsets.only( top: 150.0, left: 50, right: 50 ),
          child: Container(
            height: 200,
            width: double.infinity,
            child: Card(
              color: Colors.white,
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular( 12.0 ),
              ),
              elevation: 10.0,
              child: Padding(
                padding: const EdgeInsets.all( 16.0 ),
                child: Form(
                  child: Column(
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.only( left: 25, right: 25 ),
                        child: TextFormField(
                          controller: _textEditingControllerInformeSenha,
                          keyboardType: TextInputType.text,
                          obscureText: true,
                          textInputAction: TextInputAction.next,
                          decoration: InputDecoration(
                            labelText: "Informe a senha"
                          ),
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.only( top: 25 ),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Container(
                              width: 100,
                              child: RaisedButton(
                                color: _param.fnClosed.buttonColor,
                                textColor: Colors.white,
                                padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                                child: Text(
                                  "Fechar",
                                  style: TextStyle( fontSize: 20.0 ),
                                ),
                                onPressed: ( ) {
                                  _param.fnClosed.onClosed();
                                }
                              )
                            ),
                            Padding( padding: EdgeInsets.only( left: 20 ) ),
                            Container(
                              width: 100,
                              child: RaisedButton(
                                color: _param.fnOpened.buttonColor,
                                textColor: Colors.white,
                                elevation: 5.0,
                                padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                                child: Text(
                                  "Abrir",
                                  style: TextStyle( fontSize: 20.0 ),
                                ),
                                onPressed: (){
                                  _param.fnOpened.onOpened( _textEditingControllerInformeSenha.text );
                                }
                              )
                            )
                          ],
                        )
                      )
                    ],
                  ),
                ),
              ),
            )
          )
        )
      ],
    );
  }
}
